@@ -14,6 +14,7 @@ LANDUSE_MODULE = "LanduseModule"
 TRIP_MODULE = "TripModule"
 VEHICLE_MODULE = "VehicleModule"
 WEATHER_MODULE = "WeatherModule"
+CARTO_PIPELINE = "CartoPipeline"
 
 MASTER_MODULE = "MasterModule"
 
@@ -28,6 +29,7 @@ LIST_MODULES = [
     TRIP_MODULE,
     VEHICLE_MODULE,
     WEATHER_MODULE,
+    CARTO_PIPELINE,
 
     MASTER_MODULE
 ]
@@ -323,6 +325,40 @@ DICT_METRICS.add(metric_name="base_gps_distance_sum", data_place_str="druid", ra
 DICT_METRICS.add(metric_name="base_gps_distance_sum", data_place_str="fetch", raw_name="sumMetre", module=GPS_RAW_MODULE)
 
 
+# CartoPipeline
+DICT_METRICS.add(metric_name="score_map_route_distance_exactness", type_=np.float64)
+DICT_METRICS.add(metric_name="score_map_route_distance_exactness", data_place_str="druid", raw_name="score_map_route_distance_exactness")
+DICT_METRICS.add(metric_name="score_map_route_distance_exactness", data_place_str="fetch", raw_name="restoredDistanceExactnessScore", module=CARTO_PIPELINE)
+
+DICT_METRICS.add(metric_name="score_map_route_distance_precision", type_=np.float64)
+DICT_METRICS.add(metric_name="score_map_route_distance_precision", data_place_str="druid", raw_name="score_map_route_distance_precision")
+# DICT_METRICS.add(metric_name="score_map_route_distance_precision", data_place_str="fetch", raw_name="restoredDistancePrecisionScore", module=CARTO_PIPELINE)
+
+DICT_METRICS.add(metric_name="score_map_route_path_exactness", type_=np.float64)
+DICT_METRICS.add(metric_name="score_map_route_path_exactness", data_place_str="druid", raw_name="score_map_route_path_exactness")
+DICT_METRICS.add(metric_name="score_map_route_path_exactness", data_place_str="fetch", raw_name="restoredPathExactnessScore", module=CARTO_PIPELINE)
+
+DICT_METRICS.add(metric_name="score_map_route_path_precision", type_=np.float64)
+DICT_METRICS.add(metric_name="score_map_route_path_precision", data_place_str="druid", raw_name="score_map_route_path_precision")
+DICT_METRICS.add(metric_name="score_map_route_path_precision", data_place_str="fetch", raw_name="restoredPathPrecisionScore", module=CARTO_PIPELINE)
+
+DICT_METRICS.add(metric_name="score_raw_distance_exactness", type_=np.float64)
+DICT_METRICS.add(metric_name="score_raw_distance_exactness", data_place_str="druid", raw_name="score_raw_distance_exactness")
+DICT_METRICS.add(metric_name="score_raw_distance_exactness", data_place_str="fetch", raw_name="rawDistanceExactnessScore", module=CARTO_PIPELINE)
+
+DICT_METRICS.add(metric_name="score_raw_distance_precision", type_=np.float64)
+DICT_METRICS.add(metric_name="score_raw_distance_precision", data_place_str="druid", raw_name="score_raw_distance_precision")
+# DICT_METRICS.add(metric_name="score_raw_distance_precision", data_place_str="fetch", raw_name="rawDistancePrecisionScore", module=CARTO_PIPELINE)
+
+DICT_METRICS.add(metric_name="score_raw_path_exactness", type_=np.float64)
+DICT_METRICS.add(metric_name="score_raw_path_exactness", data_place_str="druid", raw_name="score_raw_path_exactness")
+DICT_METRICS.add(metric_name="score_raw_path_exactness", data_place_str="fetch", raw_name="rawPathExactnessScore", module=CARTO_PIPELINE)
+
+DICT_METRICS.add(metric_name="score_raw_path_precision", type_=np.float64)
+DICT_METRICS.add(metric_name="score_raw_path_precision", data_place_str="druid", raw_name="score_raw_path_precision")
+DICT_METRICS.add(metric_name="score_raw_path_precision", data_place_str="fetch", raw_name="rawPathPrecisionScore", module=CARTO_PIPELINE)
+
+
 # Druid
 DICT_METRICS.add(metric_name="raw_sensor_odometer", type_=str)
 DICT_METRICS.add(metric_name="raw_sensor_odometer", data_place_str="druid", raw_name="raw_sensor_odometerv")
@@ -330,30 +366,6 @@ DICT_METRICS.add(metric_name="raw_sensor_odometer", data_place_str="druid", raw_
 DICT_METRICS.add(metric_name="recurrent_trip_id", type_=str)
 DICT_METRICS.add(metric_name="recurrent_trip_id", data_place_str="druid", raw_name="recurrent_trip_id")
 
-DICT_METRICS.add(metric_name="score_map_route_distance_exactness", type_=np.float64)
-DICT_METRICS.add(metric_name="score_map_route_distance_exactness", data_place_str="druid", raw_name="score_map_route_distance_exactness")
-
-DICT_METRICS.add(metric_name="score_map_route_distance_precision", type_=np.float64)
-DICT_METRICS.add(metric_name="score_map_route_distance_precision", data_place_str="druid", raw_name="score_map_route_distance_precision")
-
-DICT_METRICS.add(metric_name="score_map_route_path_exactness", type_=np.float64)
-DICT_METRICS.add(metric_name="score_map_route_path_exactness", data_place_str="druid", raw_name="score_map_route_path_exactness")
-
-DICT_METRICS.add(metric_name="score_map_route_path_precision", type_=np.float64)
-DICT_METRICS.add(metric_name="score_map_route_path_precision", data_place_str="druid", raw_name="score_map_route_path_precision")
-
-DICT_METRICS.add(metric_name="score_raw_distance_exactness", type_=np.float64)
-DICT_METRICS.add(metric_name="score_raw_distance_exactness", data_place_str="druid", raw_name="score_raw_distance_exactness")
-
-DICT_METRICS.add(metric_name="score_raw_distance_precision", type_=np.float64)
-DICT_METRICS.add(metric_name="score_raw_distance_precision", data_place_str="druid", raw_name="score_raw_distance_precision")
-
-DICT_METRICS.add(metric_name="score_raw_path_exactness", type_=np.float64)
-DICT_METRICS.add(metric_name="score_raw_path_exactness", data_place_str="druid", raw_name="score_raw_path_exactness")
-
-DICT_METRICS.add(metric_name="score_raw_path_precision", type_=np.float64)
-DICT_METRICS.add(metric_name="score_raw_path_precision", data_place_str="druid", raw_name="score_raw_path_precision")
-
 DICT_METRICS.add(metric_name="raw_gps_accuracy", type_=np.float64)
 DICT_METRICS.add(metric_name="raw_gps_accuracy", data_place_str="druid", raw_name="raw_gps_accuracy")
 
@@ -375,14 +387,12 @@ DICT_METRICS.add(metric_name="map_road_type", data_place_str="druid", raw_name="
 DICT_METRICS.add(metric_name="map_gps_coordinates", type_=str)
 DICT_METRICS.add(metric_name="map_gps_coordinates", data_place_str="druid", raw_name="map_gps_coordinates")
 
-
 DICT_METRICS.add(metric_name="map_road_speed_limit", type_=np.float64)
 DICT_METRICS.add(metric_name="map_road_speed_limit", data_place_str="druid", raw_name="map_road_speed_limit")
 
 DICT_METRICS.add(metric_name="map_road_density", type_=np.int64)
 DICT_METRICS.add(metric_name="map_road_density", data_place_str="druid", raw_name="map_road_density")
 
-
 DICT_METRICS.add(metric_name="map_elevation", type_=str)
 DICT_METRICS.add(metric_name="map_elevation", data_place_str="druid", raw_name="map_elevation")
 
